==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/overview/GTTestsMSAEditorOverview.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
#ifndef GTTESTSMSAEDITOROVERVIEW_H
#define GTTESTSMSAEDITOROVERVIEW_H

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor_overview {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor_overview"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_msa_editor_overview

}  // namespace U2
#endif  // GTTESTSMSAEDITOROVERVIEW_H

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/overview/GTTestsMSAEditorOverview.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
#pragma once

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor_overview {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor_overview"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_msa_editor_overview

}  // namespace U2
